# BalderHub Package `balderhub-selenium`

This is a BalderHub package for the [Balder](https://docs.balder.dev) test framework. It provides features for working
with the [selenium framework](https://www.selenium.dev/) to automate web browsing. If you are new to Balder check out 
the [official documentation](https://docs.balder.dev) first.

## Installation

You can install the latest release with pip:

```
python -m pip install balderhub-selenium
```

# Check out the documentation

If you need more information, 
[checkout the ``balderhub-selenium`` documentation](https://hub.balder.dev/projects/selenium).


# License

This BalderHub package is free and Open-Source

Copyright (c) 2024 Max Stahlschmidt and others

Distributed under the terms of the MIT license